@@ -20,6 +20,7 @@
 
 #include <kwidgetsaddons_version.h>
 #include <kactioncollection.h>
+#include <kcountryflagemojiiconengine.h>
 #include <QMenu>
 #include <kmessagebox.h>
 #include <KLocalizedString>
@@ -34,6 +35,7 @@
 #include <QDebug>
 
 #include "textextension.h"
+#include "browserextension.h"
 
 static const KAboutData aboutdata(QStringLiteral("babelfish"), i18n("Translate Web Page"), QStringLiteral("1.0"));
 K_PLUGIN_CLASS_WITH_JSON(PluginBabelFish, "plugin_translator.json")
@@ -57,14 +59,75 @@ PluginBabelFish::PluginBabelFish(QObject *parent,
     }
 }
 
-void PluginBabelFish::addTopLevelAction(const QString &name, const QString &text)
+static QIcon iconForLanguage(const QString &languageCode)
 {
-    QAction *a = actionCollection()->addAction(name);
+    // The 2-letter codes used internally in this plugin are language codes,
+    // but KCountryFlagEmojiIconEngine generates a flag image for a country
+    // code. So what is really wanted is "the country that is the generally
+    // recognised homeland of that language".  To obtain this a QLocale is
+    // constructed with the language code duplicated to specify a language
+    // and country.  Without that, for example, QLocale("pt") guesses Brazil
+    // for the country and generates the wrong flag, but QLocale("pt_pt")
+    // has the intended country.  Some fixes still need to be applied later.
+    const QLocale loc(languageCode+"_"+languageCode);
+    QString countryCode = QLocale::territoryToCode(loc.territory());
+
+    if (countryCode.isEmpty() && languageCode.startsWith(QStringLiteral("zt"))) {
+        // Language code "zt" is only used internally to this plugin.
+       countryCode = QStringLiteral("cn");
+    }
+    else if (loc.language() == QLocale::English && QLocale::system().territory() == QLocale::UnitedKingdom) {
+        // British English users get their own flag for that language.
+        // The original country code returned by QLocale in this case
+        // will have been "us".
+        countryCode = QStringLiteral("gb");
+    }
+    //qDebug() << languageCode << "->" << countryCode;
+
+    if (countryCode.isEmpty()) return (QIcon());
+
+    // Generate the flag icon using the Noto Emoji font.
+    // The QIcon constructor takes ownership of the QIconEngine.
+    KCountryFlagEmojiIconEngine *engine = new KCountryFlagEmojiIconEngine(countryCode);
+    return (!engine->isNull() ? QIcon(engine) : QIcon());
+}
+
+/* private */ void PluginBabelFish::addMenuAction(KActionMenu *menu, const QString &srcName, const QString &text, const QString &dstName)
+{
+    QAction *a = actionCollection()->addAction(srcName);
     a->setText(text);
-    m_menu->addAction(a);
+    a->setIcon(iconForLanguage(!dstName.isEmpty() ? dstName : srcName));
+    addMenuAction(menu, a);
     m_actionGroup.addAction(a);
 }
 
+/* private */ void PluginBabelFish::addMenuAction(KActionMenu *menu, QAction *action)
+{
+    // Insert an action into a menu, in an appropriate place so that
+    // the menu actions end up in alphabetical order in the UI language.
+    const QString actionText = KLocalizedString::removeAcceleratorMarker(action->text());
+    QList<QAction *> existingActions = menu->menu()->actions();
+    QAction *before = nullptr;
+
+    for (QAction *existingAction : std::as_const(existingActions)) {
+        const QString existingText = KLocalizedString::removeAcceleratorMarker(existingAction->text());
+        if (existingText.compare(actionText, Qt::CaseInsensitive)>0) {
+            before = existingAction;
+            break;
+        }
+    }
+
+    menu->insertAction(before, action);
+}
+
+/* private */ KActionMenu *PluginBabelFish::createMenu(const QString &languageCode, const QString &title)
+{
+    KActionMenu *menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), title, actionCollection());
+    menu->setIcon(iconForLanguage(languageCode));
+    actionCollection()->addAction(QStringLiteral("translatewebpage_")+languageCode, menu);
+    return (menu);
+}
+
 void PluginBabelFish::slotAboutToShow()
 {
     if (!m_menu->menu()->actions().isEmpty()) { // already populated
@@ -76,32 +139,15 @@ void PluginBabelFish::slotAboutToShow()
     // Create a menu for each "source->dest" translation possibility where
     // there's more than one dest for a given source.
 
-    KActionMenu *menu_en = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&English To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_en"), menu_en);
-
-    KActionMenu *menu_fr = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&French To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_fr"), menu_fr);
-
-    KActionMenu *menu_de = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&German To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_de"), menu_de);
-
-    KActionMenu *menu_el = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Greek To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_el"), menu_el);
-
-    KActionMenu *menu_es = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Spanish To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_es"), menu_es);
-
-    KActionMenu *menu_pt = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Portuguese To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_pt"), menu_pt);
-
-    KActionMenu *menu_it = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Italian To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_it"), menu_it);
-
-    KActionMenu *menu_nl = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Dutch To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_nl"), menu_nl);
-
-    KActionMenu *menu_ru = new KActionMenu(QIcon::fromTheme(QStringLiteral("babelfish")), i18n("&Russian To"), actionCollection());
-    actionCollection()->addAction(QStringLiteral("translatewebpage_ru"), menu_ru);
+    KActionMenu *menu_en = createMenu(QStringLiteral("en"), i18n("&English To"));
+    KActionMenu *menu_fr = createMenu(QStringLiteral("fr"), i18n("&French To"));
+    KActionMenu *menu_de = createMenu(QStringLiteral("de"), i18n("&German To"));
+    KActionMenu *menu_el = createMenu(QStringLiteral("el"), i18n("&Greek To"));
+    KActionMenu *menu_es = createMenu(QStringLiteral("es"), i18n("&Spanish To"));
+    KActionMenu *menu_pt = createMenu(QStringLiteral("pt"), i18n("&Portuguese To"));
+    KActionMenu *menu_it = createMenu(QStringLiteral("it"), i18n("&Italian To"));
+    KActionMenu *menu_nl = createMenu(QStringLiteral("nl"), i18n("&Dutch To"));
+    KActionMenu *menu_ru = createMenu(QStringLiteral("ru"), i18n("&Russian To"));
 
     // List of translation possibilities for filling the above menus
     // Mostly from babelfish.
@@ -164,10 +210,8 @@ void PluginBabelFish::slotAboutToShow()
         const QString srcLang = translation.left(underScorePos);
         QAction *srcAction = actionCollection()->action(QLatin1String("translatewebpage_") + srcLang);
         if (KActionMenu *actionMenu = qobject_cast<KActionMenu *>(srcAction)) {
-            QAction *a = actionCollection()->addAction(translation);
-            m_actionGroup.addAction(a);
-            a->setText(entry.name.toString());
-            actionMenu->addAction(a);
+            const QString destLang = translation.mid(underScorePos+1);
+            addMenuAction(actionMenu, translation, entry.name.toString(), destLang);
         } else {
             qWarning() << "No menu found for" << srcLang;
         }
@@ -176,25 +220,20 @@ void PluginBabelFish::slotAboutToShow()
     // Fill the toplevel menu, both with single source->dest possibilities
     // and with submenus.
 
-    addTopLevelAction(QStringLiteral("zh_en"), i18n("&Chinese (Simplified) to English"));
-    addTopLevelAction(QStringLiteral("zt_en"), i18n("Chinese (&Traditional) to English"));
+    addMenuAction(m_menu, menu_nl);
+    addMenuAction(m_menu, menu_en);
+    addMenuAction(m_menu, menu_fr);
+    addMenuAction(m_menu, menu_de);
+    addMenuAction(m_menu, menu_el);
+    addMenuAction(m_menu, menu_it);
+    addMenuAction(m_menu, menu_pt);
+    addMenuAction(m_menu, menu_ru);
+    addMenuAction(m_menu, menu_es);
 
-    m_menu->addAction(menu_nl);
-    m_menu->addAction(menu_en);
-    m_menu->addAction(menu_fr);
-    m_menu->addAction(menu_de);
-    m_menu->addAction(menu_el);
-    m_menu->addAction(menu_it);
-
-    addTopLevelAction(QStringLiteral("ja_en"), i18n("&Japanese to English"));
-    addTopLevelAction(QStringLiteral("ko_en"), i18n("&Korean to English"));
-
-    m_menu->addAction(menu_pt);
-    m_menu->addAction(menu_ru);
-    m_menu->addAction(menu_es);
-
-    // TODO we could sort the action texts alphabetically, so that they wouldn't
-    // be sorted in English only...
+    addMenuAction(m_menu, QStringLiteral("zh_en"), i18n("&Chinese (Simplified) to English"));
+    addMenuAction(m_menu, QStringLiteral("zt_en"), i18n("Chinese (&Traditional) to English"));
+    addMenuAction(m_menu, QStringLiteral("ja_en"), i18n("&Japanese to English"));
+    addMenuAction(m_menu, QStringLiteral("ko_en"), i18n("&Korean to English"));
 }
 
 PluginBabelFish::~PluginBabelFish()
@@ -389,7 +428,6 @@ which may fetch the insecure version of the page."),
             }
         }
     } else {
-
         const QStringList parts = language.split('_');
 
         if (hasSelection) { //https://translate.google.com/#en|de|text_to_translate
@@ -411,7 +449,12 @@ which may fetch the insecure version of the page."),
     }
 
     // Connect to the fish
-    emit ext->openUrlRequest(result);
+    // copied from plugins/akregator/konqfeedicon.cpp
+    if (auto browserExtension = qobject_cast<BrowserExtension *>(ext)) {
+        emit browserExtension->browserOpenUrlRequest(result);
+    } else {
+        emit ext->openUrlRequest(result);
+    }
 }
 
 #include <plugin_babelfish.moc>
