@@ -1,7 +1,7 @@
 #include "cache/cache.h"
 #include <KPluginFactory>
 
-K_PLUGIN_CLASS_WITH_JSON(Cache, "khtml_cache.json")
+K_PLUGIN_CLASS_WITH_JSON(Cache, "cache/khtml_cache.json")
 
 #include "khtml_cache.moc"
 
