@@ -1,7 +1,7 @@
 #include "useragent/useragent.h"
 #include <KPluginFactory>
 
-K_PLUGIN_CLASS_WITH_JSON(UserAgent, "khtml_useragent.json")
+K_PLUGIN_CLASS_WITH_JSON(UserAgent, "useragent/khtml_useragent.json")
 
 #include "khtml_useragent.moc"
 
