@@ -22,6 +22,7 @@
 #include "konqmisc.h"
 #include <config-konqueror.h>
 #include "implementations/konqbrowser.h"
+#include "konqsettings.h"
 
 #include "interfaces/browser.h"
 
@@ -36,6 +37,7 @@
 
 #include <QtGui/private/qtx11extras_p.h>
 
+#include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -155,73 +157,73 @@ void KonquerorApplication::slotComboCleared(const QDBusMessage &msg)
 
 void KonquerorApplication::setupAboutData()
 {
-    KAboutData m_aboutData("konqueror", i18n("Konqueror"), KONQUEROR_VERSION);
-    m_aboutData.setShortDescription(i18n("Web browser, file manager and document viewer."));
-    m_aboutData.addLicense(KAboutLicense::GPL_V2);
-    m_aboutData.setCopyrightStatement(i18n("(C) 1999-2023, The Konqueror developers"));
-    m_aboutData.setHomepage("https://apps.kde.org/konqueror");
-    m_aboutData.setDesktopFileName("konqbrowser");
+    KAboutData aboutData("konqueror", i18n("Konqueror"), KONQUEROR_VERSION);
+    aboutData.setShortDescription(i18n("Web browser, file manager and document viewer."));
+    aboutData.addLicense(KAboutLicense::GPL_V2);
+    aboutData.setCopyrightStatement(i18n("(C) 1999-2023, The Konqueror developers"));
+    aboutData.setHomepage("https://apps.kde.org/konqueror");
+    aboutData.setDesktopFileName("konqbrowser");
 
     // The window icon, retrieved in KAboutApplicationDialogPrivate::init(),
     // may vary for this application depending on what is displayed.  Set the
     // program logo explicitly for the "About Konqueror" dialogue.
-    m_aboutData.setProgramLogo(QIcon::fromTheme("konqueror"));
+    aboutData.setProgramLogo(QIcon::fromTheme("konqueror"));
 
     // However, the icon for the "About <application>" action, generated
     // in KStandardAction::_k_createInternal(), uses the window icon directly.
     // This may again change later, but set it here for the action.
     QGuiApplication::setWindowIcon(QIcon::fromTheme("konqueror"));
 
-    m_aboutData.addAuthor(i18n("Stefano Crocco"), i18n("Current maintainer"), "stefano.crocco@alice.it");
-    m_aboutData.addAuthor(i18n("David Faure"), i18n("Developer (framework, parts, JavaScript, I/O library) and former maintainer"), "faure@kde.org");
-    m_aboutData.addAuthor(i18n("Simon Hausmann"), i18n("Developer (framework, parts)"), "hausmann@kde.org");
-    m_aboutData.addAuthor(i18n("Michael Reiher"), i18n("Developer (framework)"), "michael.reiher@gmx.de");
-    m_aboutData.addAuthor(i18n("Matthias Welk"), i18n("Developer"), "welk@fokus.gmd.de");
-    m_aboutData.addAuthor(i18n("Alexander Neundorf"), i18n("Developer (List views)"), "neundorf@kde.org");
-    m_aboutData.addAuthor(i18n("Michael Brade"), i18n("Developer (List views, I/O library)"), "brade@kde.org");
-    m_aboutData.addAuthor(i18n("Lars Knoll"), i18n("Developer (HTML rendering engine)"), "knoll@kde.org");
-    m_aboutData.addAuthor(i18n("Dirk Mueller"), i18n("Developer (HTML rendering engine)"), "mueller@kde.org");
-    m_aboutData.addAuthor(i18n("Peter Kelly"), i18n("Developer (HTML rendering engine)"), "pmk@post.com");
-    m_aboutData.addAuthor(i18n("Waldo Bastian"), i18n("Developer (HTML rendering engine, I/O library)"), "bastian@kde.org");
-    m_aboutData.addAuthor(i18n("Germain Garand"), i18n("Developer (HTML rendering engine)"), "germain@ebooksfrance.org");
-    m_aboutData.addAuthor(i18n("Leo Savernik"), i18n("Developer (HTML rendering engine)"), "l.savernik@aon.at");
-    m_aboutData.addAuthor(i18n("Stephan Kulow"), i18n("Developer (HTML rendering engine, I/O library, regression test framework)"), "coolo@kde.org");
-    m_aboutData.addAuthor(i18n("Antti Koivisto"), i18n("Developer (HTML rendering engine)"), "koivisto@kde.org");
-    m_aboutData.addAuthor(i18n("Zack Rusin"),  i18n("Developer (HTML rendering engine)"), "zack@kde.org");
-    m_aboutData.addAuthor(i18n("Tobias Anton"), i18n("Developer (HTML rendering engine)"), "anton@stud.fbi.fh-darmstadt.de");
-    m_aboutData.addAuthor(i18n("Lubos Lunak"), i18n("Developer (HTML rendering engine)"), "l.lunak@kde.org");
-    m_aboutData.addAuthor(i18n("Maks Orlovich"), i18n("Developer (HTML rendering engine, JavaScript)"), "maksim@kde.org");
-    m_aboutData.addAuthor(i18n("Allan Sandfeld Jensen"), i18n("Developer (HTML rendering engine)"), "kde@carewolf.com");
-    m_aboutData.addAuthor(i18n("Apple Safari Developers"), i18n("Developer (HTML rendering engine, JavaScript)"));
-    m_aboutData.addAuthor(i18n("Harri Porten"), i18n("Developer (JavaScript)"), "porten@kde.org");
-    m_aboutData.addAuthor(i18n("Koos Vriezen"), i18n("Developer (Java applets and other embedded objects)"), "koos.vriezen@xs4all.nl");
-    m_aboutData.addAuthor(i18n("Matt Koss"), i18n("Developer (I/O library)"), "koss@miesto.sk");
-    m_aboutData.addAuthor(i18n("Alex Zepeda"), i18n("Developer (I/O library)"), "zipzippy@sonic.net");
-    m_aboutData.addAuthor(i18n("Richard Moore"), i18n("Developer (Java applet support)"), "rich@kde.org");
-    m_aboutData.addAuthor(i18n("Dima Rogozin"), i18n("Developer (Java applet support)"), "dima@mercury.co.il");
-    m_aboutData.addAuthor(i18n("Wynn Wilkes"), i18n("Developer (Java 2 security manager support,\n and other major improvements to applet support)"), "wynnw@calderasystems.com");
-    m_aboutData.addAuthor(i18n("Stefan Schimanski"), i18n("Developer (Netscape plugin support)"), "schimmi@kde.org");
-    m_aboutData.addAuthor(i18n("George Staikos"), i18n("Developer (SSL, Netscape plugins)"), "staikos@kde.org");
-    m_aboutData.addAuthor(i18n("Dawit Alemayehu"), i18n("Developer (I/O library, Authentication support)"), "adawit@kde.org");
-    m_aboutData.addAuthor(i18n("Carsten Pfeiffer"), i18n("Developer (framework)"), "pfeiffer@kde.org");
-    m_aboutData.addAuthor(i18n("Torsten Rahn"), i18n("Graphics/icons"), "torsten@kde.org");
-    m_aboutData.addAuthor(i18n("Torben Weis"), i18n("KFM author"), "weis@kde.org");
-    m_aboutData.addAuthor(i18n("Joseph Wenninger"), i18n("Developer (navigation panel framework)"), "jowenn@kde.org");
-    m_aboutData.addAuthor(i18n("Stephan Binner"), i18n("Developer (misc stuff)"), "binner@kde.org");
-    m_aboutData.addAuthor(i18n("Ivor Hewitt"), i18n("Developer (AdBlock filter)"), "ivor@ivor.org");
-    m_aboutData.addAuthor(i18n("Eduardo Robles Elvira"), i18n("Developer (framework)"), "edulix@gmail.com");
-    m_aboutData.addAuthor(i18n("Matthias Kalle Dalheimer"), QLatin1String(""), QStringLiteral("kalle@kde.org"));
-    m_aboutData.addAuthor(i18n("Daniel Molkentin"), QLatin1String(""), QStringLiteral("molkentin@kde.org"));
-    m_aboutData.addCredit(i18n("Leo Savernik"), i18n("JavaScript access controls\n"
+    aboutData.addAuthor(i18n("Stefano Crocco"), i18n("Current maintainer"), "stefano.crocco@alice.it");
+    aboutData.addAuthor(i18n("David Faure"), i18n("Developer (framework, parts, JavaScript, I/O library) and former maintainer"), "faure@kde.org");
+    aboutData.addAuthor(i18n("Simon Hausmann"), i18n("Developer (framework, parts)"), "hausmann@kde.org");
+    aboutData.addAuthor(i18n("Michael Reiher"), i18n("Developer (framework)"), "michael.reiher@gmx.de");
+    aboutData.addAuthor(i18n("Matthias Welk"), i18n("Developer"), "welk@fokus.gmd.de");
+    aboutData.addAuthor(i18n("Alexander Neundorf"), i18n("Developer (List views)"), "neundorf@kde.org");
+    aboutData.addAuthor(i18n("Michael Brade"), i18n("Developer (List views, I/O library)"), "brade@kde.org");
+    aboutData.addAuthor(i18n("Lars Knoll"), i18n("Developer (HTML rendering engine)"), "knoll@kde.org");
+    aboutData.addAuthor(i18n("Dirk Mueller"), i18n("Developer (HTML rendering engine)"), "mueller@kde.org");
+    aboutData.addAuthor(i18n("Peter Kelly"), i18n("Developer (HTML rendering engine)"), "pmk@post.com");
+    aboutData.addAuthor(i18n("Waldo Bastian"), i18n("Developer (HTML rendering engine, I/O library)"), "bastian@kde.org");
+    aboutData.addAuthor(i18n("Germain Garand"), i18n("Developer (HTML rendering engine)"), "germain@ebooksfrance.org");
+    aboutData.addAuthor(i18n("Leo Savernik"), i18n("Developer (HTML rendering engine)"), "l.savernik@aon.at");
+    aboutData.addAuthor(i18n("Stephan Kulow"), i18n("Developer (HTML rendering engine, I/O library, regression test framework)"), "coolo@kde.org");
+    aboutData.addAuthor(i18n("Antti Koivisto"), i18n("Developer (HTML rendering engine)"), "koivisto@kde.org");
+    aboutData.addAuthor(i18n("Zack Rusin"),  i18n("Developer (HTML rendering engine)"), "zack@kde.org");
+    aboutData.addAuthor(i18n("Tobias Anton"), i18n("Developer (HTML rendering engine)"), "anton@stud.fbi.fh-darmstadt.de");
+    aboutData.addAuthor(i18n("Lubos Lunak"), i18n("Developer (HTML rendering engine)"), "l.lunak@kde.org");
+    aboutData.addAuthor(i18n("Maks Orlovich"), i18n("Developer (HTML rendering engine, JavaScript)"), "maksim@kde.org");
+    aboutData.addAuthor(i18n("Allan Sandfeld Jensen"), i18n("Developer (HTML rendering engine)"), "kde@carewolf.com");
+    aboutData.addAuthor(i18n("Apple Safari Developers"), i18n("Developer (HTML rendering engine, JavaScript)"));
+    aboutData.addAuthor(i18n("Harri Porten"), i18n("Developer (JavaScript)"), "porten@kde.org");
+    aboutData.addAuthor(i18n("Koos Vriezen"), i18n("Developer (Java applets and other embedded objects)"), "koos.vriezen@xs4all.nl");
+    aboutData.addAuthor(i18n("Matt Koss"), i18n("Developer (I/O library)"), "koss@miesto.sk");
+    aboutData.addAuthor(i18n("Alex Zepeda"), i18n("Developer (I/O library)"), "zipzippy@sonic.net");
+    aboutData.addAuthor(i18n("Richard Moore"), i18n("Developer (Java applet support)"), "rich@kde.org");
+    aboutData.addAuthor(i18n("Dima Rogozin"), i18n("Developer (Java applet support)"), "dima@mercury.co.il");
+    aboutData.addAuthor(i18n("Wynn Wilkes"), i18n("Developer (Java 2 security manager support,\n and other major improvements to applet support)"), "wynnw@calderasystems.com");
+    aboutData.addAuthor(i18n("Stefan Schimanski"), i18n("Developer (Netscape plugin support)"), "schimmi@kde.org");
+    aboutData.addAuthor(i18n("George Staikos"), i18n("Developer (SSL, Netscape plugins)"), "staikos@kde.org");
+    aboutData.addAuthor(i18n("Dawit Alemayehu"), i18n("Developer (I/O library, Authentication support)"), "adawit@kde.org");
+    aboutData.addAuthor(i18n("Carsten Pfeiffer"), i18n("Developer (framework)"), "pfeiffer@kde.org");
+    aboutData.addAuthor(i18n("Torsten Rahn"), i18n("Graphics/icons"), "torsten@kde.org");
+    aboutData.addAuthor(i18n("Torben Weis"), i18n("KFM author"), "weis@kde.org");
+    aboutData.addAuthor(i18n("Joseph Wenninger"), i18n("Developer (navigation panel framework)"), "jowenn@kde.org");
+    aboutData.addAuthor(i18n("Stephan Binner"), i18n("Developer (misc stuff)"), "binner@kde.org");
+    aboutData.addAuthor(i18n("Ivor Hewitt"), i18n("Developer (AdBlock filter)"), "ivor@ivor.org");
+    aboutData.addAuthor(i18n("Eduardo Robles Elvira"), i18n("Developer (framework)"), "edulix@gmail.com");
+    aboutData.addAuthor(i18n("Matthias Kalle Dalheimer"), QLatin1String(""), QStringLiteral("kalle@kde.org"));
+    aboutData.addAuthor(i18n("Daniel Molkentin"), QLatin1String(""), QStringLiteral("molkentin@kde.org"));
+    aboutData.addCredit(i18n("Leo Savernik"), i18n("JavaScript access controls\n"
                      "Per-domain policies extensions"),
                      QStringLiteral("l.savernik@aon.at"));
-    KAboutData::setApplicationData(m_aboutData);
+    KAboutData::setApplicationData(aboutData);
 }
 
 void KonquerorApplication::setupParser()
 {
     m_parser.setSingleDashWordOptionMode(QCommandLineParser::ParseAsLongOptions);
-    m_aboutData.setupCommandLine(&m_parser);
+    KAboutData::applicationData().setupCommandLine(&m_parser);
 
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("silent")}, i18n("Start without a default window, when called without URLs")));
     m_parser.addOption(QCommandLineOption(QStringList{QStringLiteral("preload")}, i18n("Preload for later use. This mode does not support URLs on the command line")));
@@ -303,7 +305,7 @@ int KonquerorApplication::start()
     KCrash::initialize();
 
     m_parser.process(*this);
-    m_aboutData.processCommandLine(&m_parser);
+    KAboutData::applicationData().processCommandLine(&m_parser);
 
     //This can't be done in performStart, because it must be done before creating the
     //DBus service. Otherwise, the list of session will be printed in the standard output
@@ -379,9 +381,11 @@ int KonquerorApplication::performStart(const QString& workingDirectory, bool fir
 
     bool sessionRestored = KonqSessionManager::self()->restoreSessionSavedAtExit();
     if (!args.isEmpty()) {
-        //KonqSessionManager::restoreSessionSavedAtExit only returns true if there's at least one main window,
-        //so there's no need to check whether the list is empty
-        result = createWindowsForUrlArguments(args, workingDirectory, sessionRestored ? KonqMainWindow::mainWindows().at(0) : nullptr);
+        KonqMainWindow *mw = nullptr;
+        if (Konq::Settings::konquerorTabforExternalURL() || sessionRestored) {
+            mw = KonqMainWindow::mostSuitableWindow();
+        }
+        result = createWindowsForUrlArguments(args, workingDirectory, mw);
     } else if (sessionRestored){
         result = WindowCreationResult{KonqMainWindow::mainWindows().at(0), 0};
     } else {
@@ -438,12 +442,14 @@ KonquerorApplication::WindowCreationResult KonquerorApplication::createWindowsFo
 
     QUrl firstUrl = urlList.takeFirst();
 
+    KonqOpenURLRequest req;
+
     KParts::OpenUrlArguments urlargs;
     if (m_parser.isSet("mimetype")) {
         urlargs.setMimeType(m_parser.value("mimetype"));
+        req.forceMimeType = true;
     }
 
-    KonqOpenURLRequest req;
     req.args = urlargs;
     req.filesToSelect = filesToSelect;
     req.tempFile = m_parser.isSet("tempfile");
